@@ -10,7 +10,9 @@ from botocore_stubber_recorder.request import APICall
 from botocore_stubber_recorder.format import is_black_on_path, format_source_code
 
 env = Environment(
-    loader=PackageLoader("botocore_stubber_recorder"), autoescape=select_autoescape()
+    loader=PackageLoader("botocore_stubber_recorder"),
+    autoescape=select_autoescape(),
+    extensions=["jinja2_ansible_filters.AnsibleCoreFiltersExtension"],
 )
 
 
@@ -92,10 +94,13 @@ class UnitTestGenerator:
         test_directory = os.path.join(self.directory, self.name)
         os.makedirs(test_directory, exist_ok=True)
 
-        filename = os.path.join(test_directory, "__init__.py")
-        if not os.path.exists(filename):
-            with open(filename, "w") as file:
-                pass
+        for directory in [self.directory, test_directory]:
+            filename = os.path.join(directory, "__init__.py")
+            if not os.path.exists(filename):
+                with open(filename, "w") as file:
+                    file.write(
+                        "# generated by botocore-stubber-recorder but will not be overwritten by it"
+                    )
 
         filename = os.path.join(test_directory, "base.py")
         with open(filename, "w") as file:
@@ -106,9 +111,12 @@ class UnitTestGenerator:
         filename = os.path.join(test_directory, f"test_{self.name}.py")
         if not os.path.exists(filename):
             with open(filename, "w") as file:
-                self.unittest_template.stream(generator=self, recorder=recorder).dump(
-                    file
-                )
+                self.unittest_template.stream(
+                    generator=self,
+                    recorder=recorder,
+                    anonimize=anonimize,
+                    unflatten=unflatten,
+                ).dump(file)
         else:
             logging.info("%s already exists, not overwritten", filename)
 
